@@ -8,7 +8,7 @@ use vars qw(@ISA $VERSION);
 use Net::LDAP::Control;
 
 @ISA = qw(Net::LDAP::Control);
-$VERSION = "0.01";
+$VERSION = "0.03";
 
 use Net::LDAP::ASN qw(VirtualListViewResponse);
 use strict;
@@ -22,10 +22,10 @@ sub init {
   else {
     my $asn = $self->{asn} = {};
 
-    $asn->{targetPosition}        = $self->{target}  || 0;
-    $asn->{contentCount}          = $self->{content} || 0;
-    $asn->{virtualListViewResult} = $self->{result}  || 0;
-    $asn->{context}               = $self->{context} || undef;
+    $asn->{targetPosition}        = $self->{target}    || 0;
+    $asn->{contentCount}          = $self->{content}   || 0;
+    $asn->{virtualListViewResult} = $self->{result}    || 0;
+    $asn->{contextID}             = $self->{contextID} || undef;
   }
 
   $self;
@@ -63,9 +63,9 @@ sub context {
   my $self = shift;
   if (@_) {
     delete $self->{value};
-    return $self->{asn}{context} = shift;
+    return $self->{asn}{contextID} = shift;
   }
-  $self->{asn}{context};
+  $self->{asn}{contextID};
 }
 
 sub value {
@@ -94,11 +94,11 @@ Net::LDAP::Control::VLVResponse -- LDAPv3 Virtual List View server response
 
 =head1 SYNOPSIS
 
-See L<Net::LDAP::Control::VLV|Net::LDAP::Control::VLV>
+See L<Net::LDAP::Control::VLV>
 
 =head1 DESCRIPTION
 
-C<Net::LDAP::Control::VLVResponse> is a sub-class of L<Net::LDAP::Control|Net::LDAP::Control>.
+C<Net::LDAP::Control::VLVResponse> is a sub-class of L<Net::LDAP::Control>.
 It provides a class for manipulating the LDAP Virtual List View Response control
 C<>
 
@@ -108,7 +108,7 @@ include a VLVResponse control.
 =head1 CONSTRUCTOR ARGUMENTS
 
 In addition to the constructor arguments described in
-L<Net::LDAP::Control|Net::LDAP::Control> the following are provided.
+L<Net::LDAP::Control> the following are provided.
 
 =over 4
 
@@ -137,14 +137,14 @@ The list offset of the target entry.
 
 =head1 METHODS
 
-As with L<Net::LDAP::Control|Net::LDAP::Control> each constructor argument
+As with L<Net::LDAP::Control> each constructor argument
 described above is also avaliable as a method on the object which will
 return the current value for the attribute if called without an argument,
 and set a new value for the attribute if called with an argument.
 
 =head1 RESULT CODES
 
-Possible results from a sort request are listed below. See L<Net::LDAP::Constant|Net::LDAP::Constant> for
+Possible results from a sort request are listed below. See L<Net::LDAP::Constant> for
 a definition of each.
 
 =over 4
@@ -173,16 +173,15 @@ a definition of each.
 
 =head1 SEE ALSO
 
-L<Net::LDAP|Net::LDAP>,
-L<Net::LDAP::Control|Net::LDAP::Control>,
-http://info.internet.isi.edu/in-notes/rfc/files/rfc2696.txt
+L<Net::LDAP>,
+L<Net::LDAP::Control>
 
 =head1 AUTHOR
 
-Graham Barr <gbarr@pobox.com>
+Graham Barr E<lt>gbarr@pobox.comE<gt>
 
 Please report any bugs, or post any suggestions, to the perl-ldap mailing list
-<perl-ldap-dev@lists.sourceforge.net>
+E<lt>perl-ldap@perl.orgE<gt>
 
 =head1 COPYRIGHT
 
@@ -192,7 +191,7 @@ terms as Perl itself.
 
 =for html <hr>
 
-I<$Id: VLVResponse.pm,v 1.3 2000/07/30 21:03:50 gbarr Exp $>
+I<$Id: VLVResponse.pm,v 1.6 2003/05/07 11:59:14 chrisridd Exp $>
 
 =cut
 
